@@ -44,3 +44,6 @@ class ContentFile(Framework.TestCase):
         self.assertEqual(len(self.file.content), 10212)
         self.assertEqual(len(self.file.decoded_content), 7531)
         self.assertEqual(self.file.sha, "5628799a7d517a4aaa0c1a7004d07569cd154df0")
+
+        # test __repr__() based on this attributes
+        self.assertEqual(self.file.__repr__(), 'ContentFile(path="ReadMe.md")')
\ No newline at end of file
